@@ -70,8 +70,6 @@ var categoryMgr = Components.classes["@mozilla.org/categorymanager;1"]
                             .getService(Components.interfaces.nsICategoryManager);
 var mimeSvc = Components.classes["@mozilla.org/mime;1"]
                         .getService(Components.interfaces.nsIMIMEService);
-var ioSvc = Components.classes["@mozilla.org/network/io-service;1"]
-                      .getService(Components.interfaces.nsIIOService);
 var converterSvc = Components.classes["@mozilla.org/embeddor.implemented/web-content-handler-registrar;1"]
                              .getService(Components.interfaces.nsIWebContentConverterService);
 var shellSvc = null;
@@ -140,7 +138,7 @@ const kActionManageApp = -1;
 // Utilities
 
 function getFileDisplayName(aFile) {
-//@line 157 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/common/pref/pref-applications.js"
+//@line 155 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/common/pref/pref-applications.js"
   return aFile.leafName;
 }
 
@@ -898,9 +896,7 @@ var gApplicationsPane = {
     this._rebuildView();
 
     // Notify observers that the UI is now ready
-    Components.classes["@mozilla.org/observer-service;1"]
-              .getService(Components.interfaces.nsIObserverService)
-              .notifyObservers(window, "app-handler-pane-loaded", null);
+    Services.obs.notifyObservers(window, "app-handler-pane-loaded", null);
   },
 
   destroy: function() {
@@ -1284,9 +1280,9 @@ var gApplicationsPane = {
 // XXXben - we need to compare this with the running instance executable
 //          just don't know how to do that via script...
 // XXXmano TBD: can probably add this to nsIShellService
-//@line 1306 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/common/pref/pref-applications.js"
+//@line 1302 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/common/pref/pref-applications.js"
    aExecutable.leafName != "-bin";
-//@line 1309 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/common/pref/pref-applications.js"
+//@line 1305 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/common/pref/pref-applications.js"
   },
 
   /**
@@ -1425,7 +1421,7 @@ var gApplicationsPane = {
     }
 
     // Create a menu item for selecting a local application.
-//@line 1453 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/common/pref/pref-applications.js"
+//@line 1449 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/common/pref/pref-applications.js"
     {
       let menuItem = document.createElement("menuitem");
       menuItem.setAttribute("class", "handler-action");
@@ -1605,7 +1601,7 @@ var gApplicationsPane = {
   chooseApp: function() {
     var handlerApp;
 
-//@line 1660 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/common/pref/pref-applications.js"
+//@line 1656 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/common/pref/pref-applications.js"
     var fp = Components.classes["@mozilla.org/filepicker;1"]
                        .createInstance(nsIFilePicker);
     var winTitle = this._prefsBundle.getString("fpTitleChooseApp");
@@ -1625,7 +1621,7 @@ var gApplicationsPane = {
       let handlerInfo = this._handledTypes[this._list.selectedItem.type];
       handlerInfo.addPossibleApplicationHandler(handlerApp);
     }
-//@line 1680 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/common/pref/pref-applications.js"
+//@line 1676 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/common/pref/pref-applications.js"
 
     // Rebuild the actions menu whether the user picked an app or canceled.
     // If they picked an app, we want to add the app to the menu and select it.
@@ -1716,15 +1712,15 @@ var gApplicationsPane = {
   },
 
   _getIconURLForFile: function(aFile) {
-    var fph = ioSvc.getProtocolHandler("file")
-                   .QueryInterface(Components.interfaces.nsIFileProtocolHandler);
+    var fph = Services.io.getProtocolHandler("file")
+                         .QueryInterface(Components.interfaces.nsIFileProtocolHandler);
     var urlSpec = fph.getURLSpecFromFile(aFile);
 
     return "moz-icon://" + urlSpec + "?size=16";
   },
 
   _getIconURLForWebApp: function(aWebAppURITemplate) {
-    var uri = ioSvc.newURI(aWebAppURITemplate, null, null);
+    var uri = Services.io.newURI(aWebAppURITemplate, null, null);
 
     // Unfortunately we need to use favicon.ico here, but we don't know
     // about any other possibility to retrieve an icon for the web app/site
