@@ -189,10 +189,6 @@ pref("browser.urlbar.restrict.typed", "~");
 pref("browser.urlbar.match.title", "#");
 pref("browser.urlbar.match.url", "@");
 
-// Whether or not microsummary and generator updates are enabled.
-pref("browser.microsummary.enabled", true);
-pref("browser.microsummary.updateGenerators", true);
-
 pref("browser.history.grouping", "day");
 pref("browser.sessionhistory.max_entries", 50);
 
@@ -361,13 +357,13 @@ pref("accessibility.blockautorefresh", false);
 // Use the findbar for type ahead find, instead of the XPFE implementation
 pref("accessibility.typeaheadfind.usefindbar", true);
 pref("accessibility.typeaheadfind.flashBar", 0);
-//@line 367 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
+//@line 363 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
 
-//@line 371 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
+//@line 367 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
 pref("browser.preferences.instantApply", true);
-//@line 376 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
+//@line 372 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 378 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
+//@line 374 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
 
 pref("browser.download.show_plugins_in_list", true);
 pref("browser.download.hide_plugins_without_extensions", true);
@@ -509,13 +505,14 @@ pref("app.update.cert.maxErrors", 5);
 // |app.update.url.override| preference for update checking.
 pref("app.update.certs.1.issuerName", "OU=Equifax Secure Certificate Authority,O=Equifax,C=US");
 pref("app.update.certs.1.commonName", "aus2-community.mozilla.org");
+pref("app.update.certs.2.issuerName", "CN=GeoTrust SSL CA,O=\"GeoTrust, Inc.\",C=US");
+pref("app.update.certs.2.commonName", "aus2-community.mozilla.org");
+pref("app.update.certs.3.issuerName", "CN=Thawte SSL CA,O=\"Thawte, Inc.\",C=US");
+pref("app.update.certs.3.commonName", "aus2-community.mozilla.org");
 
 // Interval: Time between checks for a new version (in seconds)
 //           default=1 day
 pref("app.update.interval", 86400);
-// Interval: Time before prompting the user again to restart to install the
-//           latest download (in seconds) default=1 day
-pref("app.update.nagTimer.restart", 86400);
 // The minimum delay in seconds for the timer to fire.
 // default=2 minutes
 pref("app.update.timerMinimumDelay", 120);
@@ -544,8 +541,12 @@ pref("extensions.logging.enabled", false);
 // Blocklist preferences
 pref("extensions.blocklist.enabled", true);
 pref("extensions.blocklist.interval", 86400);
+// Controls what level the blocklist switches from warning about items to forcibly
+// blocking them.
+pref("extensions.blocklist.level", 2);
 pref("extensions.blocklist.url", "https://addons.mozilla.org/blocklist/3/%APP_ID%/%APP_VERSION%/%PRODUCT%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/%PING_COUNT%/%TOTAL_PING_COUNT%/%DAYS_SINCE_LAST_PING%/");
 pref("extensions.blocklist.detailsURL", "https://www.mozilla.com/%LOCALE%/blocklist/");
+pref("extensions.blocklist.itemURL", "https://addons.mozilla.org/%LOCALE%/%APP%/blocked/%blockID%");
 
 // Update preferences for installed Extensions and Themes.
 // Symmetric (can be overridden by individual extensions),
@@ -592,7 +593,7 @@ pref("custtoolbar.personal_toolbar_folder", "");
 // Use a popup window for the customize toolbar UI
 pref("toolbar.customization.usesheet", false);
 
-//@line 612 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
+//@line 611 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
 
 pref("sidebar.customize.all_panels.url", "http://sidebar-rdf.netscape.com/%LOCALE%/sidebar-rdf/%SIDEBAR_VERSION%/all-panels.rdf");
 pref("sidebar.customize.directory.url", "http://dmoz.org/Netscape/Sidebar/");
@@ -662,9 +663,9 @@ pref("dom.event.contextmenu.enabled",  true);
 
 // The default for this pref reflects whether the build is capable of IPC.
 // (Turning it on in a no-IPC build will have no effect.)
-//@line 699 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
+//@line 698 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
 pref("dom.ipc.plugins.enabled", true);
-//@line 703 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
+//@line 700 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
 
 // plugin finder service url
 pref("pfs.datasource.url", "https://pfs.mozilla.org/plugins/PluginFinderService.php?mimetype=%PLUGIN_MIMETYPE%&appID=%APP_ID%&appVersion=%APP_VERSION%&clientOS=%CLIENT_OS%&chromeLocale=%CHROME_LOCALE%");
@@ -674,14 +675,14 @@ pref("plugins.hide_infobar_for_outdated_plugin", false);
 pref("plugins.hide_infobar_for_carbon_failure_plugin", false);
 pref("plugins.hide_infobar_for_missing_plugin", false);
 
-//@line 713 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
+//@line 710 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
 // Restore the spinner that was removed in bug 481359
 pref("ui.use_activity_cursor", true);
-//@line 716 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
+//@line 713 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
+
+//@line 728 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
 
 //@line 731 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
-
-//@line 734 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
 // For the download dialog
 pref("browser.download.progressDnldDialog.enable_launch_reveal_buttons", false);
 pref("browser.urlbar.clickSelectsAll", false);
@@ -694,7 +695,7 @@ pref("browser.backspace_action", 2);
 pref("general.autoScroll", false);
 
 pref("layout.word_select.stop_at_punctuation", false);
-//@line 748 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
+//@line 745 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
 
 // The breakpad report server to link to in about:crashes
 pref("breakpad.reportURL", "http://crash-stats.mozilla.com/report/index/");
@@ -708,7 +709,7 @@ pref("browser.geolocation.warning.infoURL", "http://www.seamonkey-project.org/do
 pref("browser.rights.version", 1);
 pref("browser.rights.1.shown", false);
 
-//@line 768 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
+//@line 765 "/builds/slave/rel-comm-rel-lnx64-bld/build/suite/browser/browser-prefs.js"
 
 // The sync engines to use.
 pref("services.sync.registerEngines", "Bookmarks,Form,History,Password,Prefs,Tab");
