@@ -39,7 +39,8 @@ const PREFS_WHITELIST = [
   "places.",
   "print.",
   "privacy.",
-  "security."
+  "security.",
+  "webgl."
 ];
 
 // The blacklist, unlike the whitelist, is a list of regular expressions.
@@ -130,6 +131,64 @@ function populateGraphicsSection() {
     return elem;
   }
 
+  function pushInfoRow(table, name, value)
+  {
+    if(value) {
+      table.push(createParentElement("tr", [
+        createHeader(bundle.GetStringFromName(name)),
+        createElement("td", value),
+      ]));
+    }
+  }
+
+  function errorMessageForFeature(feature) {
+    var errorMessage;
+    var status;
+    try {
+      status = gfxInfo.getFeatureStatus(feature);
+    } catch(e) {}
+    switch (status) {
+      case gfxInfo.FEATURE_BLOCKED_DEVICE:
+      case gfxInfo.FEATURE_DISCOURAGED:
+        errorMessage = bundle.GetStringFromName("blockedGfxCard");
+        break;
+      case gfxInfo.FEATURE_BLOCKED_OS_VERSION:
+        errorMessage = bundle.GetStringFromName("blockedOSVersion");
+        break;
+      case gfxInfo.FEATURE_BLOCKED_DRIVER_VERSION:
+        var suggestedDriverVersion;
+        try {
+          suggestedDriverVersion = gfxInfo.getFeatureSuggestedDriverVersion(feature);
+        } catch(e) {}
+        if (suggestedDriverVersion)
+          errorMessage = bundle.formatStringFromName("tryNewerDriver", [suggestedDriverVersion], 1);
+        else
+          errorMessage = bundle.GetStringFromName("blockedDriver");
+        break;
+    }
+    return errorMessage;
+  }
+
+  function pushFeatureInfoRow(table, name, feature, isEnabled, message) {
+    message = message || isEnabled;
+    if (!isEnabled) {
+      var errorMessage = errorMessageForFeature(feature);
+      if (errorMessage)
+        message = errorMessage;
+    }
+    table.push(createParentElement("tr", [
+      createHeader(bundle.GetStringFromName(name)),
+      createElement("td", message),
+    ]));
+  }
+
+  function hexValueToString(value)
+  {
+    return value
+           ? String('0000' + value.toString(16)).slice(-4)
+           : null;
+  }
+
   let bundle = Services.strings.createBundle("chrome://global/locale/aboutSupport.properties");
   let graphics_tbody = document.getElementById("graphics-tbody");
 
@@ -141,95 +200,29 @@ function populateGraphicsSection() {
 
   if (gfxInfo) {
     let trGraphics = [];
-    trGraphics.push(createParentElement("tr", [
-      createHeader(bundle.GetStringFromName("adapterDescription")),
-      createElement("td", gfxInfo.adapterDescription),
-    ]));
-    trGraphics.push(createParentElement("tr", [
-      createHeader(bundle.GetStringFromName("adapterVendorID")),
-      // pad with zeros. (printf would be nicer)
-      createElement("td", String('0000'+gfxInfo.adapterVendorID.toString(16)).slice(-4)),
-    ]));
-    trGraphics.push(createParentElement("tr", [
-      createHeader(bundle.GetStringFromName("adapterDeviceID")),
-      // pad with zeros. (printf would be nicer)
-      createElement("td", String('0000'+gfxInfo.adapterDeviceID.toString(16)).slice(-4)),
-    ]));
-    trGraphics.push(createParentElement("tr", [
-      createHeader(bundle.GetStringFromName("adapterRAM")),
-      createElement("td", gfxInfo.adapterRAM),
-    ]));
-    trGraphics.push(createParentElement("tr", [
-      createHeader(bundle.GetStringFromName("adapterDrivers")),
-      createElement("td", gfxInfo.adapterDriver),
-    ]));
-    trGraphics.push(createParentElement("tr", [
-      createHeader(bundle.GetStringFromName("driverVersion")),
-      createElement("td", gfxInfo.adapterDriverVersion),
-    ]));
-    trGraphics.push(createParentElement("tr", [
-      createHeader(bundle.GetStringFromName("driverDate")),
-      createElement("td", gfxInfo.adapterDriverDate),
-    ]));
+    pushInfoRow(trGraphics, "adapterDescription", gfxInfo.adapterDescription);
+    pushInfoRow(trGraphics, "adapterVendorID", hexValueToString(gfxInfo.adapterVendorID));
+    pushInfoRow(trGraphics, "adapterDeviceID", hexValueToString(gfxInfo.adapterDeviceID));
+    pushInfoRow(trGraphics, "adapterRAM", gfxInfo.adapterRAM);
+    pushInfoRow(trGraphics, "adapterDrivers", gfxInfo.adapterDriver);
+    pushInfoRow(trGraphics, "driverVersion", gfxInfo.adapterDriverVersion);
+    pushInfoRow(trGraphics, "driverDate", gfxInfo.adapterDriverDate);
 
-    var d2dEnabled = false;
-    try {
-      d2dEnabled = gfxInfo.D2DEnabled;
-    } catch(e) {}
-    var d2dMessage = d2dEnabled;
-    if (!d2dEnabled) {
-      var d2dStatus = -1; // different from any status value defined in the IDL
-      try {
-        d2dStatus = gfxInfo.getFeatureStatus(gfxInfo.FEATURE_DIRECT2D);
-      } catch(e) {
-        window.dump(e + '\n');
-      }  
-      if (d2dStatus == gfxInfo.FEATURE_BLOCKED_DEVICE ||
-          d2dStatus == gfxInfo.FEATURE_DISCOURAGED)
-      {
-        d2dMessage = bundle.GetStringFromName("blockedGraphicsCard");
-      }
-      else if (d2dStatus == gfxInfo.FEATURE_BLOCKED_DRIVER_VERSION)
-      {
-        var d2dSuggestedDriverVersion = null;
-        try {
-          d2dSuggestedDriverVersion = gfxInfo.getFeatureSuggestedDriverVersion(gfxInfo.FEATURE_DIRECT2D);
-        } catch(e) {
-          window.dump(e + '\n');
-        }
-        if (d2dSuggestedDriverVersion) {
-          d2dMessage = bundle.GetStringFromName("tryNewerDriverVersion").replace("%1", d2dSuggestedDriverVersion);
-        }
-      }
-    }
-    trGraphics.push(createParentElement("tr", [
-      createHeader(bundle.GetStringFromName("direct2DEnabled")),
-      createElement("td", d2dMessage),
-    ]));
-
-    var dwEnabled = false;
-    var dwriteEnabledStr = dwEnabled.toString();
-    var dwriteVersion;
-    try {
-      dwEnabled = gfxInfo.DWriteEnabled;
-      dwriteVersion = gfxInfo.DWriteVersion;
-      dwriteEnabledStr = dwEnabled.toString() + " (" + dwriteVersion + ")";
-    } catch(e) {}
-    trGraphics.push(createParentElement("tr", [
-      createHeader(bundle.GetStringFromName("directWriteEnabled")),
-      createElement("td", dwriteEnabledStr),
-    ]));
+//@line 275 "/builds/slave/rel-comm-rel-lnx64-bld/build/mozilla/toolkit/content/aboutSupport.js"
 
     var webglrenderer;
+    var webglenabled;
     try {
       webglrenderer = gfxInfo.getWebGLParameter("full-renderer");
+      webglenabled = true;
     } catch (e) {
-      webglrenderer = "(WebGL unavailable)";
+      webglrenderer = false;
+      webglenabled = false;
     }
-    trGraphics.push(createParentElement("tr", [
-      createHeader(bundle.GetStringFromName("webglRenderer")),
-      createElement("td", webglrenderer)
-    ]));
+//@line 293 "/builds/slave/rel-comm-rel-lnx64-bld/build/mozilla/toolkit/content/aboutSupport.js"
+    var webglfeature = gfxInfo.FEATURE_WEBGL_OPENGL;
+//@line 295 "/builds/slave/rel-comm-rel-lnx64-bld/build/mozilla/toolkit/content/aboutSupport.js"
+    pushFeatureInfoRow(trGraphics, "webglRenderer", webglfeature, webglenabled, webglrenderer);
 
     appendChildren(graphics_tbody, trGraphics);
    
@@ -260,8 +253,16 @@ function populateGraphicsSection() {
   }
 
   let msg = acceleratedWindows + "/" + totalWindows;
-  if (acceleratedWindows)
+  if (acceleratedWindows) {
     msg += " " + mgrType;
+  } else {
+//@line 332 "/builds/slave/rel-comm-rel-lnx64-bld/build/mozilla/toolkit/content/aboutSupport.js"
+    var feature = gfxInfo.FEATURE_OPENGL_LAYERS;
+//@line 334 "/builds/slave/rel-comm-rel-lnx64-bld/build/mozilla/toolkit/content/aboutSupport.js"
+    var errMsg = errorMessageForFeature(feature);
+    if (errMsg)
+      msg += ". " + errMsg;
+  }
 
   appendChildren(graphics_tbody, [
     createParentElement("tr", [
@@ -389,7 +390,7 @@ function createTextForElement(elem) {
   text = text.replace(/\n\n\n+/g, "\n\n");
 
   // Actual CR/LF pairs are needed for some Windows text editors.
-//@line 431 "/builds/slave/rel-comm-rel-lnx64-bld/build/mozilla/toolkit/content/aboutSupport.js"
+//@line 468 "/builds/slave/rel-comm-rel-lnx64-bld/build/mozilla/toolkit/content/aboutSupport.js"
 
   return text;
 }
